@@ -155,6 +155,8 @@ void JobModel::getJobs()
                                        KCUPS_JOB_K_OCTETS,
                                        KCUPS_JOB_K_OCTETS_PROCESSED,
                                        KCUPS_JOB_STATE,
+                                       KCUPS_JOB_STATE_REASONS,
+                                       KCUPS_JOB_HOLD_UNTIL,
                                        KCUPS_TIME_AT_COMPLETED,
                                        KCUPS_TIME_AT_CREATION,
                                        KCUPS_TIME_AT_PROCESSING,
@@ -345,6 +347,8 @@ void JobModel::updateJob(int pos, const KCupsJob &job)
         colStatus->setData(pages, RoleJobPages);
     }
 
+    colStatus->setData(job.authenticationRequired(), RoleJobAuthenticationRequired);
+
     // internal dest name & column
     const QString destName = job.printer();
     if (colStatus->data(RoleJobPrinter).toString() != destName) {
@@ -401,7 +405,7 @@ void JobModel::updateJob(int pos, const KCupsJob &job)
         colPages->setText(QString::number(completedPages));
     }
 
-    // when it was precessed
+    // when it was processed
     const QDateTime timeAtProcessing = job.processedAt();
     QStandardItem *colProcessed = item(pos, ColProcessed);
     if (colProcessed->data(Qt::DisplayRole).toDateTime() != timeAtProcessing) {
